@@ -73,7 +73,8 @@ MR AB AND M/S CD VAN DER HEIDEN-MACNAY
  MR AS & D.E. DE LA MARE
 ESTATE OF THE LATE AB LE FONTAIN
 BIG BROTHER & THE HOLDING COMPANY
-MR PAUL J KEATING
+MR KA MACQUARIE
+RIGHT HONOURABLE MR PJ KEATING
 MR TOM JONES
 EDWARD G WHITLAM
 JAMES BROWN
